@@ -6,9 +6,6 @@ sub test_start_emacs {
     local $@;
     eval { run [$emacs, '--version'], \undef, \$out };
     plan skip_all => "Failed to start Emacs, cannot test module" if $@;
-    BAIL_OUT("Unknown Emacs version" . ($out =~ /^(.*)$/ ? ": $1" : ""))
-	unless $out =~ /(\w+\s?emacs\s+\d+(?:\.\d+)*)/i;
-
     $out
 }
 sub test_start_client {
